# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-06-27 19:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0041_event_extras'),
    ]

    operations = [
        migrations.AddField(
            model_name='eventagendaitem',
            name='plain_text',
            field=models.TextField(null=True),
        ),
    ]
