<p>
  This site has data from the current legislative session.
  If you're searching for something older, you can browse the
  <a href="{{ LEGISTAR_URL }}" target="_blank">
      {{ CITY_COUNCIL_NAME }} Legistar site
  </a>.
</p>
<p>We'd be happy to help you find what you're looking for -
  <a href="mailto:info@councilmatic.org">contact us</a>!
</p>