<input name="q" type="text" class="input-lg form-control" placeholder="{{ SEARCH_PLACEHOLDER_TEXT }}" value="{{ formatted_q }}">
<div class='input-group-btn'>
    <button type="submit" class="btn btn-lg btn-primary">
        <i class='fa fa-fw fa-search'></i>
    </button>
</div>