# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-10-05 19:37
from __future__ import unicode_literals

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0042_eventagendaitem_plain_text'),
    ]

    operations = [
        migrations.AddField(
            model_name='membership',
            name='extras',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
    ]
